import { __decorate } from "tslib";
import { computeLabel, isDescriptionHidden } from '@jsonforms/core';
import { html, css, when, observable, customElement, FASTElement, volatile, attr, } from '@microsoft/fast-element';
import { classNames } from '@microsoft/fast-web-utilities';
export const ControlWrapperRendererTemplate = html `
  <template>
    ${when((x) => { var _a; return (_a = x.control) === null || _a === void 0 ? void 0 : _a.visible; }, html `
        <div
          class=${(x) => {
    var _a, _b, _c, _d;
    return classNames(['wrapperRoot', true], ['labelLeft', ((_d = (_c = (_b = (_a = x.jsonForms) === null || _a === void 0 ? void 0 : _a.core) === null || _b === void 0 ? void 0 : _b.uischema) === null || _c === void 0 ? void 0 : _c.options) === null || _d === void 0 ? void 0 : _d.labelPlacement) === 'left']);
}}
          id=${(x) => x.control.path + '-wrapper'}
          data-test-id=${(x) => x.control.path + '-wrapper'}
        >
          ${when((x) => !x.hideLabel, html `
              <div for="${(x) => x.control.path + '-wrapper'}" class="label">
                <span>
                  ${(x) => x.computedLabel}${when((x) => { var _a, _b; return (_b = (_a = x.control.uischema) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.tooltip; }, (x) => x.getPrefixedTooltip)}
                </span>
              </div>
            `)}

          <div class="wrapper">
            <slot></slot>
          </div>
          <div class="${(x) => (x.control.errors && x.touched ? 'error' : 'description')}">
            ${(x) => x.control.errors && x.touched
    ? x.control.errors
    : x.showDescription
        ? x.control.description
        : ''}
          </div>
        </div>
      `)}
  </template>
`;
const styles = css `
  .wrapperRoot {
    margin-bottom: calc(var(--design-unit) * 4px);
  }

  .wrapperRoot.labelLeft {
    display: flex;
    flex-wrap: wrap;
  }

  .label {
    color: var(--neutral-foreground-hint);
    margin-bottom: calc(var(--design-unit) * 1px);
    display: flex;
    justify-content: space-between;
  }

  .labelLeft .wrapper {
    flex: 1 1 auto;
    width: auto;
    align-items: flex-start;
    flex-wrap: wrap;
  }

  .labelLeft .label {
    flex: 0 1 auto;
    width: calc(var(--design-unit) * 30px);
    margin-right: calc(var(--design-unit) * 2px);
    align-items: center;
    margin-bottom: 0;
  }

  .labelLeft .error {
    margin-left: 0;
    flex: 1 1 100%;
    text-align: right;
  }

  .error {
    font-size: 12px;
    color: #f9644d;
    margin-left: 10px;
  }

  .wrapper {
    display: flex;
    width: 100%;
    align-items: center;
  }
`;
let ControlWrapper = class ControlWrapper extends FASTElement {
    constructor() {
        super(...arguments);
        this.hideLabel = false;
    }
    get showDescription() {
        return !isDescriptionHidden(this.control.visible, this.control.description, this.control.isFocused, !!this.control.config.showUnfocusedDescription);
    }
    get computedLabel() {
        return computeLabel(this.control.label, this.control.required, !!this.control.config.hideRequiredAsterisk);
    }
    get getPrefixedTooltip() {
        var _a, _b;
        return html `
    <${this.prefix}-icon tooltip="${(_b = (_a = this.control.uischema) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.tooltip}" tooltip-id="${this.control.path + '-tooltip'}"></${this.prefix}-icon>`;
    }
};
__decorate([
    observable
], ControlWrapper.prototype, "control", void 0);
__decorate([
    observable
], ControlWrapper.prototype, "jsonForms", void 0);
__decorate([
    observable
], ControlWrapper.prototype, "touched", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'hide-label' })
], ControlWrapper.prototype, "hideLabel", void 0);
__decorate([
    attr
], ControlWrapper.prototype, "prefix", void 0);
__decorate([
    volatile
], ControlWrapper.prototype, "showDescription", null);
__decorate([
    volatile
], ControlWrapper.prototype, "computedLabel", null);
__decorate([
    volatile
], ControlWrapper.prototype, "getPrefixedTooltip", null);
ControlWrapper = __decorate([
    customElement({
        name: 'control-wrapper',
        styles,
        template: ControlWrapperRendererTemplate,
    })
], ControlWrapper);
export { ControlWrapper };
